@@ -7,7 +7,7 @@ To run the server type::
 Open a new shell and launch python and type::
 
     >>> from pulsar.apps import rpc
-    >>> p = rpc.JsonProxy('http://localhost:8060', force_sync=True)
+    >>> p = rpc.JsonProxy('http://localhost:8060')
     >>> p.ping()
     'pong'
     >>> p.functions_list()
@@ -15,21 +15,21 @@ Open a new shell and launch python and type::
     >>> p.calc.add(3,4)
     7.0
 
-The ``force_sync`` keyword is used here to force the Json RPC client to
-wait for a full response rather than returning a :class:`pulsar.Deferred`.
-Check the :ref:`creating synchronous clients <tutorials-synchronous>` tutorial.
-
 Implementation
 -----------------
 
 The calculator rpc functions are implemented by the :class:`Calculator`
 handler, while the :class:`Root` handler exposes utility methods from
-the :class:`pulsar.apps.rpc.PulsarServerCommands` handler.
+the :class:`.PulsarServerCommands` handler.
 
 .. autoclass:: Calculator
    :members:
    :member-order: bysource
 
+.. autoclass:: Root
+   :members:
+   :member-order: bysource
+
 .. autoclass:: Site
    :members:
    :member-order: bysource
@@ -43,20 +43,22 @@ except ImportError:  # pragma nocover
 
 from random import normalvariate
 
-from pulsar import async
+from pulsar import coroutine_return
 from pulsar.apps import rpc, wsgi
 from pulsar.utils.httpurl import JSON_CONTENT_TYPES
 from pulsar.utils.pep import range
 
 
 def divide(request, a, b):
-    '''Divide two numbers. This method illustrate how to use the
-:func:`pulsar.apps.rpc.rpc_method` decorator.'''
+    '''Divide two numbers.
+
+    This method illustrate how to use the :func:`.rpc_method` decorator.'''
     return float(a)/float(b)
 
 
 def request_handler(request, format, kwargs):
-    '''Dummy request handler'''
+    '''Dummy request handler for test coverage
+    '''
     return kwargs
 
 
@@ -75,26 +77,28 @@ def randompaths(request, num_paths=1, size=250, mu=0, sigma=1):
 
 class RequestCheck:
 
-    #async()
     def __call__(self, request, name):
         data = yield request.body_data()
         assert(data['method'] == name)
-        yield True
+        coroutine_return(True)
 
 
 class Root(rpc.PulsarServerCommands):
-
+    '''Add two rpc methods for testing to the :class:`.PulsarServerCommands`
+    handler.
+    '''
     def rpc_dodgy_method(self, request):
         '''This method will fails because the return object is not
-json serializable.'''
+        json serializable.'''
         return Calculator
 
     rpc_check_request = RequestCheck()
 
 
 class Calculator(rpc.JSONRPC):
-    '''A :class:`pulsar.apps.rpc.JSONRPC` handler which implements few simple
-remote functions.'''
+    '''A :class:`.JSONRPC` handler which implements few simple
+    remote methods.
+    '''
     def rpc_add(self, request, a, b):
         '''Add two numbers'''
         return float(a) + float(b)
@@ -113,7 +117,7 @@ remote functions.'''
 
 class Site(wsgi.LazyWsgi):
     '''WSGI handler for the RPC server'''
-    def setup(self):
+    def setup(self, environ):
         '''Called once to setup the list of wsgi middleware.'''
         json_handler = Root().putSubHandler('calc', Calculator())
         middleware = wsgi.Router('/', post=json_handler,
