@@ -14,6 +14,7 @@ try:
 except ImportError:  # pragma nocover
     sys.path.append('../../')
     import pulsar
+
 from pulsar.apps import ws, wsgi
 from pulsar.utils.pep import range
 from pulsar.utils.system import json
@@ -21,6 +22,9 @@ from pulsar.utils.system import json
 
 class Graph(ws.WS):
 
+    def on_open(self, websocket):
+        self.on_message(websocket, '')
+
     def on_message(self, websocket, msg):
         websocket.write(json.dumps([(i, random()) for i in range(100)]))
 
@@ -30,13 +34,15 @@ class Echo(ws.WS):
     def on_message(self, websocket, msg):
         if msg.startswith('send ping '):
             websocket.ping(msg[10:])
+        elif msg.startswith('send close '):
+            websocket.write_close(int(msg[11:]))
         else:
             websocket.write(msg)
 
 
 class Site(wsgi.LazyWsgi):
 
-    def setup(self):
+    def setup(self, environ):
         return wsgi.WsgiHandler([wsgi.Router('/', get=self.home),
                                  ws.WebSocket('/data', Graph()),
                                  ws.WebSocket('/echo', Echo())])
