@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -
 '''Event driven concurrent framework for Python'''
-VERSION = (0, 8, 0, 'final', 0)
+VERSION = (0, 8, 1, 'final', 0)
 
 import os
 
@@ -60,4 +60,6 @@ if os.environ.get('pulsar_setup_running') != 'yes':
 
     del get_version
     # Import data stores
+    from .apps.data import stores
+    del stores
     from .apps.data import data_stores
