@@ -146,8 +146,8 @@ def monitor_info(self, info=None):
 
 def monitor_params(self, params=None):
     app = self.app
-    params.update({'cfg': app.cfg.copy(),
-                   'name': '{0}-worker'.format(app.name),
+    params.update({'cfg': app.cfg.clone(),
+                   'name': '%s.worker' % app.name,
                    'start': worker_start})
     app.actorparams(self, params)
 
@@ -450,12 +450,11 @@ class Application(Configurator):
         if monitor is None and (not actor or actor.is_arbiter()):
             self.cfg.on_start()
             self.logger = self.cfg.configured_logger()
-            if not actor:   # arbiter not available
-                # This application is starts the arbiter
-                cfg = Config()
-                cfg.update(self.arbiter_params())
-                actor = pulsar.arbiter(cfg=cfg)
-                self.cfg.set('exc_id', actor.cfg.exc_id)
+            if not actor:
+                actor = pulsar.arbiter(cfg=self.cfg.clone())
+            else:
+                self.update_arbiter_params(actor)
+            self.cfg.set('exc_id', actor.cfg.exc_id)
             if self.on_config(actor) is not False:
                 start = Future(loop=actor._loop)
                 actor.bind_event('start', partial(self._add_monitor, start))
@@ -504,9 +503,12 @@ class Application(Configurator):
         at each event loop.'''
         pass
 
-    def arbiter_params(self):
-        return dict(((s.name, s.value) for s in self.cfg.settings.values()
-                     if s.is_global))
+    def update_arbiter_params(self, arbiter):
+        for s in self.cfg.settings.values():
+            if s.is_global and s.modified:
+                a = arbiter.cfg.settings[s.name]
+                if not a.modified:
+                    a.set(s.value)
 
     #   INTERNALS
     def _add_monitor(self, start, arbiter, exc=None):
@@ -621,7 +623,7 @@ class MultiApp(Configurator):
     def __call__(self, actor=None):
         return multi_async((app(actor) for app in self.apps()))
 
-    ##    INTERNALS
+    #    INTERNALS
     def _iter_app(self, app_name_callables):
         main = app_name_callables.pop('', None)
         if not main:
