@@ -79,12 +79,14 @@ And the backend will be selected via::
 '''
 import sys
 import time
+from functools import partial
 from datetime import datetime, timedelta
 from hashlib import sha1
 
 from pulsar import (task, async, EventHandler, PulsarException, get_logger,
                     Future, coroutine_return, get_request_loop)
 from pulsar.utils.pep import itervalues, to_string
+from pulsar.utils.security import gen_unique_id
 from pulsar.apps.data import create_store, PubSubClient, odm
 from pulsar.utils.log import (LocalMixin, lazyproperty, lazymethod,
                               LazyString)
@@ -183,24 +185,24 @@ class TaskConsumer(object):
 
 
 class Task(odm.Model):
-    '''A model containing task execution data.
+    '''A data :class:`.Model` containing task execution data.
     '''
     id = odm.CharField(primary_key=True)
     '''Task unique identifier.
     '''
-    lock_id = odm.CharField(unique=True)
+    lock_id = odm.CharField(required=False)
     name = odm.CharField(index=True)
-    time_queued = odm.FloatField()
-    time_started = odm.FloatField()
-    time_ended = odm.FloatField()
+    time_queued = odm.FloatField(default=time.time)
+    time_started = odm.FloatField(required=False)
+    time_ended = odm.FloatField(required=False)
     '''The timestamp indicating when this has finished.
     '''
-    expiry = odm.FloatField()
+    expiry = odm.FloatField(required=False)
     '''The timestamp indicating when this task expires.
 
     If the task is not started before this value it is ``REVOKED``.
     '''
-    status = odm.IntegerField()
+    status = odm.IntegerField(index=True, default=states.QUEUED)
     '''flag indicating the :ref:`task status <task-state>`
     '''
     kwargs = odm.PickleField()
@@ -225,16 +227,6 @@ class Task(odm.Model):
         return LazyString(self.info)
 
 
-class TaskClient(PubSubClient):
-
-    def __init__(self, be):
-        self._be = be
-
-    def __call__(self, channel, message):
-        name = self._be.event_name(channel)
-        self._be.fire_event(name, message)
-
-
 class TaskBackend(EventHandler):
     '''A backend class for running :class:`.Task`.
     A :class:`TaskBackend` is responsible for creating tasks and put them
@@ -433,16 +425,16 @@ class TaskBackend(EventHandler):
         '''Create a publish/subscribe handler from the backend :attr:`store`.
         '''
         pubsub = self.store.pubsub()
-        pubsub.add_client(TaskClient(self))
+        pubsub.add_client(self)
         # pubsub channels names from event names
         channels = tuple((self.channel(name) for name in self.events))
         pubsub.subscribe(*channels)
         self.bind_event('task_done', self.task_done_callback)
         return pubsub
 
-    ########################################################################
-    ##    ABSTRACT METHODS
-    ########################################################################
+    # #######################################################################
+    # #    ABSTRACT METHODS
+    # #######################################################################
     def maybe_queue_task(self, task):
         '''Actually queue a :class:`.Task` if possible.
         '''
@@ -472,9 +464,9 @@ class TaskBackend(EventHandler):
         '''
         raise NotImplementedError()
 
-    ########################################################################
-    ##    START/CLOSE METHODS FOR TASK WORKERS
-    ########################################################################
+    # #######################################################################
+    # #    START/CLOSE METHODS FOR TASK WORKERS
+    # #######################################################################
     def start(self, worker):
         '''Invoked by the task queue ``worker`` when it starts.
         '''
@@ -493,7 +485,6 @@ class TaskBackend(EventHandler):
             self.task_poller = None
             self.logger.debug('stopped polling tasks')
         self._pubsub.close()
-            #self.store.close()
 
     def generate_task_ids(self, job, kwargs):
         '''An internal method to generate task unique identifiers.
@@ -511,7 +502,7 @@ class TaskBackend(EventHandler):
         can_overlap = job.can_overlap
         if hasattr(can_overlap, '__call__'):
             can_overlap = can_overlap(**kwargs)
-        tid = job.create_id(kwargs)
+        tid = gen_unique_id()
         if can_overlap:
             return tid, None
         else:
@@ -522,11 +513,11 @@ class TaskBackend(EventHandler):
                 name = self.name
             return tid, sha1(name.encode('utf-8')).hexdigest()
 
-    ########################################################################
-    ##    PRIVATE METHODS
-    ########################################################################
+    # #######################################################################
+    # #    PRIVATE METHODS
+    # #######################################################################
     def tick(self, now=None):
-        #Run a tick, that is one iteration of the scheduler.
+        # Run a tick, that is one iteration of the scheduler.
         if not self.schedule_periodic:
             return
         remaining_times = []
@@ -593,7 +584,7 @@ class TaskBackend(EventHandler):
 
     @task
     def may_pool_task(self, worker):
-        #Called in the ``worker`` event loop.
+        # Called in the ``worker`` event loop.
         #
         # It pools a new task if possible, and add it to the queue of
         # tasks consumed by the ``worker`` CPU-bound thread.'''
@@ -640,10 +631,9 @@ class TaskBackend(EventHandler):
                 else:
                     logger.info('starting %s', task_info)
                     kwargs = task.get('kwargs') or {}
-                    task.clear_update(id=task_id, status=states.STARTED,
-                                      time_started=time_ended,
-                                      worker=worker.aid)
-                    self.models.task.update(task)
+                    self.models.task.update(id=task_id, status=states.STARTED,
+                                            time_started=time_ended,
+                                            worker=worker.aid)
                     pubsub.publish(self.channel('task_started'), task_id)
                     # This may block for a while
                     result = yield job(consumer, **kwargs)
@@ -661,10 +651,9 @@ class TaskBackend(EventHandler):
             result = str(exc)
             status = states.FAILURE
         #
-        task.clear_update(id=task_id, time_ended=time.time(),
-                          status=status, result=result)
         try:
-            self.models.task.update(task)
+            yield self.models.task.update(id=task_id, time_ended=time.time(),
+                                          status=status, result=result)
         finally:
             self.concurrent_tasks.discard(task_id)
             self.finish_task(task_id, lock_id)
@@ -695,6 +684,11 @@ class TaskBackend(EventHandler):
         # If a callback is not available, it must have been fired already
         self.wait_for_task(task_id)
 
+    def __call__(self, channel, message):
+        # PubSub callback
+        name = self.event_name(channel)
+        self.fire_event(name, message)
+
 
 class SchedulerEntry(object):
     '''A class used as a schedule entry by the :class:`.TaskBackend`.
@@ -823,9 +817,11 @@ class PulsarTaskBackend(TaskBackend):
 
     def get_tasks(self, ids):
         base = self.models.task._meta.table_name
-        pipeline = self.models.task._read_store.pipeline()
+        store = self.models.task._read_store
+        pipeline = store.pipeline()
         for pk in ids:
-            pipeline.hgetall('%s:%s' % (base, pk), factory=Task)
+            pipeline.hgetall('%s:%s' % (base, pk),
+                             factory=partial(store.build_model, Task))
         return pipeline.commit()
 
     def flush(self):
