@@ -280,6 +280,21 @@ Test Plugin
    :members:
    :member-order: bysource
 
+Populate
+~~~~~~~~~~~~~
+
+A useful function for populating random data::
+
+    from pulsar.apps.test import populate
+
+    data = populate('string', 100)
+
+gives you a list of 100 random strings
+
+
+.. autofunction:: pulsar.apps.test.populate.populate
+
+
 Utilities
 ================
 
@@ -293,9 +308,10 @@ from functools import partial
 import pulsar
 from pulsar import multi_async
 from pulsar.apps import tasks
-from pulsar.apps.data import PulsarDS, create_store
+from pulsar.apps.data import create_store
+from pulsar.apps.ds import PulsarDS
 from pulsar.utils.log import lazyproperty
-from pulsar.utils.config import section_docs
+from pulsar.utils.config import section_docs, TestOption
 from pulsar.utils.pep import default_timer, to_string
 
 from .case import mock
@@ -308,30 +324,13 @@ from .wsgi import *
 from .pep import pep8_run
 
 
+pyver = '%s.%s' % (sys.version_info[:2])
+
 section_docs['Test'] = '''
 This section covers configuration parameters used by the
 :ref:`Asynchronous/Parallel test suite <apps-test>`.'''
 
 
-def dont_run_with_thread(obj):
-    '''Decorator for disabling process baaed test cases when the test suite
-    runs in threading, rather than processing, mode.
-    '''
-    actor = pulsar.get_actor()
-    if actor:
-        d = unittest.skipUnless(actor.cfg.concurrency == 'process',
-                                'Run only when concurrency is process')
-        return d(obj)
-    else:
-        return obj
-
-
-def mute_failure(test, failure):
-    #TODO: add test flag to control muting
-    if not test.cfg.log_failures:
-        maybe_failure(failure).mute()
-
-
 class ExitTest(Exception):
     pass
 
@@ -418,31 +417,6 @@ class TestShowLeaks(TestOption):
     """
 
 
-class TestLogFailures(TestOption):
-    name = "log_failures"
-    flags = ['--log-failures']
-    action = 'store_true'
-    default = False
-    validator = pulsar.validate_bool
-    desc = """Don't mute exceptions.
-
-    Tested exception are usually muted via mute_failure function. This
-    flag disable it.
-
-    To see the exception the log level must be at least error."""
-
-
-class RedisServer(TestOption):
-    name = 'redis_server'
-    flags = ['--redis-server']
-    meta = "CONNECTION_STRING"
-    default = '127.0.0.1:6379/9'
-    desc = 'Connection string for the redis server used in during testing'
-
-
-pyver = '%s.%s' % (sys.version_info[:2])
-
-
 class TestSuite(tasks.TaskQueue):
     '''An asynchronous test suite which works like a task queue.
 
@@ -471,7 +445,7 @@ class TestSuite(tasks.TaskQueue):
     '''
     name = 'test'
     cfg = pulsar.Config(apps=('tasks', 'test'),
-                        loglevel='none',
+                        loglevel=['none'],
                         task_paths=['pulsar.apps.test.case'],
                         plugins=())
 
@@ -492,8 +466,8 @@ class TestSuite(tasks.TaskQueue):
 
     @lazyproperty
     def loader(self):
-        #When config is available load the tests and check what type of
-        #action is required.
+        # When config is available load the tests and check what type of
+        # action is required.
         modules = self.cfg.get('modules')
         # Create a runner and configure it
         runner = self.new_runner()
@@ -512,8 +486,6 @@ class TestSuite(tasks.TaskQueue):
             return False
         stream = arbiter.stream
         stream.writeln(sys.version)
-        redis_server = 'redis://%s' % self.cfg.redis_server
-        arbiter.cfg.params['redis_server'] = redis_server
         if self.cfg.list_labels:    # pragma    nocover
             tags = self.cfg.labels
             if tags:
@@ -538,12 +510,16 @@ class TestSuite(tasks.TaskQueue):
     def monitor_start(self, monitor):
         '''When the monitor starts load all test classes into the queue'''
         # Create a datastore for this test suite
-        server = PulsarDS(bind='127.0.0.1:0', workers=0,
-                          key_value_save=[],
-                          name='%s_store' % self.name)
-        yield server()
-        store = create_store('pulsar://%s:%s' % (server.cfg.addresses[0]),
-                             pool_size=2)
+        if not self.cfg.task_backend:
+            server = PulsarDS(bind='127.0.0.1:0', workers=0,
+                              key_value_save=[],
+                              name='%s_store' % self.name)
+            yield server()
+            address = 'pulsar://%s:%s' % server.cfg.addresses[0]
+        else:
+            address = self.cfg.task_backend
+
+        store = create_store(address, pool_size=2, loop=monitor._loop)
         self.get_backend(store)
         loader = self.loader
         tags = self.cfg.labels
@@ -615,7 +591,7 @@ class TestSuite(tasks.TaskQueue):
                 self.logger.info('All tests have finished.')
                 time_taken = default_timer() - self._time_start
                 for task in tests:
-                    runner.add(task['result'])
+                    runner.add(task.get('result'))
                 runner.on_end()
                 runner.printSummary(time_taken)
                 # Shut down the arbiter
