@@ -37,8 +37,14 @@ __all__ = ['HttpServerResponse', 'MAX_CHUNK_SIZE', 'test_wsgi_environ']
 MAX_CHUNK_SIZE = 65536
 
 
+class FakeConnection(object):
+
+    def __init__(self, loop=None):
+        self._loop = loop
+
+
 def test_wsgi_environ(path='/', method=None, headers=None, extra=None,
-                      secure=False):
+                      secure=False, loop=None):
     '''An function to create a WSGI environment dictionary for testing.
 
     :param url: the resource in the ``PATH_INFO``.
@@ -57,6 +63,8 @@ def test_wsgi_environ(path='/', method=None, headers=None, extra=None,
     request_headers = Headers(headers, kind='client')
     headers = Headers()
     stream = StreamReader(request_headers, parser)
+    extra = extra or {}
+    extra['pulsar.connection'] = FakeConnection(loop=loop)
     return wsgi_environ(stream, ('127.0.0.1', 8060), '777.777.777.777:8080',
                         headers, https=secure, extra=extra)
 
@@ -129,7 +137,7 @@ class StreamReader:
         if self.waiting_expect():
             raise HttpException(status=417)
 
-    ##    INTERNALS
+    #    INTERNALS
     def _getvalue(self, body, maxbuf):
         if self.buffer:
             body = self.buffer + body
@@ -416,7 +424,7 @@ class HttpServerResponse(ProtocolConsumer):
             self.transport.write(chunk_encoding(data))
 
     ########################################################################
-    ##    INTERNALS
+    #    INTERNALS
     @in_loop
     def _response(self, environ):
         exc_info = None
@@ -504,7 +512,7 @@ class HttpServerResponse(ProtocolConsumer):
         return headers
 
     def wsgi_environ(self):
-        #return a the WSGI environ dictionary
+        # return a the WSGI environ dictionary
         transport = self.transport
         https = True if is_tls(transport.get_extra_info('socket')) else False
         multiprocess = (self.cfg.concurrency == 'process')
