@@ -39,6 +39,7 @@ __all__ = ['Future',
            'async_while',
            'in_loop',
            'task',
+           'wait_complete',
            'chain_future',
            'ASYNC_OBJECTS',
            'future_result_exc',
@@ -73,10 +74,12 @@ else:
 
 
 def coroutine_return(*value):
-    raise Return(*value)
+    error = Return(*value)
+    error.raised = True
+    raise error
 
 
-def add_errback(future, callback):
+def add_errback(future, callback, loop=None):
     '''Add a ``callback`` to a ``future`` executed only if an exception
     or cancellation has occurred.'''
     def _error_back(fut):
@@ -85,17 +88,21 @@ def add_errback(future, callback):
         elif fut.cancelled():
             callback(CancelledError())
 
+    future = async(future, loop=None)
     future.add_done_callback(_error_back)
+    return future
 
 
-def add_callback(future, callback):
+def add_callback(future, callback, loop=None):
     '''Add a ``callback`` to ``future`` executed only if an exception
     has not occurred.'''
     def _call_back(fut):
         if not (fut._exception or fut.cancelled()):
             callback(fut.result())
 
+    future = async(future, loop=None)
     future.add_done_callback(_call_back)
+    return future
 
 
 def future_timeout(future, timeout, exc_class=None):
@@ -122,7 +129,7 @@ def chain_future(future, callback=None, errback=None, next=None, timeout=None):
     ``callback`` is executed and its result set as the results of ``next``.
     If an exception occurs the optional ``errback`` is executed.
 
-    :param future: the original :class:`asyncio.Future`
+    :param future: the original :class:`asyncio.Future` (can be a coroutine)
     :param callback: optional callback to execute on the result of ``future``
     :param errback: optional callback to execute on the exception of ``future``
     :param next: optional :class:`asyncio.Future` to chain.
@@ -130,6 +137,7 @@ def chain_future(future, callback=None, errback=None, next=None, timeout=None):
     :param timeout: optional timeout to set on ``next``
     :return: the future ``next``
     '''
+    future = async(future)
     if next is None:
         next = Future(loop=future._loop)
         if timeout and timeout > 0:
@@ -140,19 +148,23 @@ def chain_future(future, callback=None, errback=None, next=None, timeout=None):
     def _callback(fut):
         try:
             try:
-                result = fut.result()
-            except Exception as exc:
+                exc = future.exception()
+            except CancelledError as e:
+                exc = e
+            if exc:
                 if errback:
+                    exc = None
                     result = errback(result)
-                else:
-                    raise
             else:
+                result = future.result()
                 if callback:
                     result = callback(result)
         except Exception as exc:
             next.set_exception(exc)
         else:
-            if isinstance(result, Future):
+            if exc:
+                next.set_exception(exc)
+            elif isinstance(result, Future):
                 chain(result, next=next)
             else:
                 next.set_result(result)
@@ -255,6 +267,23 @@ def task(method):
     return _
 
 
+def wait_complete(method):
+    '''Decorator to wait for a ``method`` to complete.
+
+    It only affects asynchronous object with a local event loop.
+    '''
+    @wraps(method)
+    def _(self, *args, **kwargs):
+        loop = self._loop
+        result = method(self, *args, **kwargs)
+        if not getattr(loop, '_iothreadloop', True) and not loop.is_running():
+            return loop.run_until_complete(async(result, loop=loop))
+        else:
+            return result
+
+    return _
+
+
 def run_in_loop(loop, callback, *args, **kwargs):
     '''Run ``callable`` in the event ``loop`` thread.
 
@@ -412,7 +441,6 @@ class Task(asyncio.Task):
     _current_tasks = {}
 
     def _step(self, value=None, exc=None):
-        __skip_traceback__ = True
         assert not self.done(), \
             '_step(): already done: {!r}, {!r}, {!r}'.format(self, value, exc)
         if self._must_cancel:
@@ -482,8 +510,9 @@ class Task(asyncio.Task):
         self = None
 
 
-############################################################### MultiFuture
+# ############################################################## MultiFuture
 class MultiFuture(Future):
+
     def __init__(self, loop, data, type=None, raise_on_error=True):
         super(MultiFuture, self).__init__(loop=loop)
         self._futures = {}
@@ -498,26 +527,31 @@ class MultiFuture(Future):
             data = enumerate(data)
         self._stream = type()
         for key, value in data:
-            if self._state == _PENDING:
-                value = self._get_set_item(key, maybe_async(value, self._loop))
-                if isinstance(value, Future):
-                    self._futures[key] = value
-                    value.add_done_callback(partial(self._future_done, key))
+            value = self._get_set_item(key, maybe_async(value, self._loop))
+            if isinstance(value, Future):
+                self._futures[key] = value
+                value.add_done_callback(partial(self._future_done, key))
+            elif self._state != _PENDING:
+                break
         self._check()
 
     @property
     def failures(self):
         return self._failures
 
-    ###    INTERNALS
+    #    INTERNALS
     def _check(self):
         if not self._futures and self._state == _PENDING:
             self.set_result(self._stream)
 
-    def _future_done(self, key, future):
-        self._futures.pop(key, None)
-        self._get_set_item(key, future)
-        self._check()
+    def _future_done(self, key, future, inthread=False):
+        if inthread or future._loop is self._loop:
+            self._futures.pop(key, None)
+            if self._state == _PENDING:
+                self._get_set_item(key, future)
+                self._check()
+        else:
+            self._loop.call_soon(self._future_done, key, future, True)
 
     def _get_set_item(self, key, value):
         if isinstance(value, Future):
