@@ -168,8 +168,8 @@ class ProtocolConsumer(EventHandler):
         if self._request is not None:
             try:
                 self.start_request()
-            except Exception:
-                self.finished(sys.exc_info())
+            except Exception as exc:
+                self.finished(exc=exc)
 
     def connection_lost(self, exc):
         '''Called by the :attr:`connection` when the transport is closed.
@@ -340,7 +340,7 @@ class PulsarProtocol(EventHandler):
         return info
 
     ########################################################################
-    ##    INTERNALS
+    #    INTERNALS
     def _timed_out(self):
         self.close()
         self.logger.debug('Closed idle %s.', self)
@@ -659,7 +659,7 @@ class TcpServer(Producer):
             self.close()
         return protocol
 
-    ##    INTERNALS
+    #    INTERNALS
     def _connection_made(self, connection, exc=None):
         if not exc:
             self._concurrent_connections.add(connection)
