@@ -31,7 +31,7 @@ from .internet import parse_address
 from .importer import import_system_file
 from .httpurl import HttpParser as PyHttpParser
 from .log import configured_logger
-from .pep import to_bytes, iteritems, native_str
+from .pep import to_bytes, iteritems, native_str, pickle
 
 
 __all__ = ['Config',
@@ -119,9 +119,10 @@ class Config(object):
     def __init__(self, description=None, epilog=None,
                  version=None, apps=None, include=None,
                  exclude=None, settings=None, prefix=None,
-                 name=None, **params):
+                 name=None, log_name=None, **params):
         self.settings = {} if settings is None else settings
         self.name = name
+        self.log_name = log_name
         self.prefix = prefix
         self.include = set(include or ())
         self.exclude = set(exclude or ())
@@ -213,7 +214,9 @@ class Config(object):
 
         If ``default`` is ``True``, the :attr:`Setting.default` is also set.
         '''
-        if name not in self.settings:
+        if name in self.__dict__:
+            self.__dict__[name] = value
+        elif name not in self.settings:
             # not in settings, check if this is a prefixed name
             if self.prefix:
                 prefix_name = '%s_%s' % (self.prefix, name)
@@ -339,34 +342,43 @@ class Config(object):
         me.params = me.params.copy()
         return me
 
+    def clone(self):
+        return pickle.loads(pickle.dumps(self))
+
     def configured_logger(self, name=None):
         '''Configured logger.
         '''
         loggers = {}
         loghandlers = self.loghandlers
-        name = 'pulsar.%s' % (name or self.name)
+        if not name and self.log_name:
+            name = self.log_name
+        else:
+            name = 'pulsar.%s' % (name or self.name)
         default_loglevel = None
         for loglevel in self.loglevel or ():
             bits = loglevel.split('.')
             loglevel = bits[-1]
             if len(bits) > 1:
                 namespace = '.'.join(bits[:-1])
-                if namespace == 'pulsar':
-                    default_loglevel = loglevel
             else:
-                if not default_loglevel:
-                    default_loglevel = loglevel
                 namespace = name
             if namespace in loggers:
                 continue
-            loggers[namespace] = configured_logger(namespace,
-                                                   config=self.logconfig,
-                                                   level=loglevel,
-                                                   handlers=loghandlers)
-        default_loglevel = default_loglevel or 'info'
+            logger = configured_logger(namespace,
+                                       config=self.logconfig,
+                                       level=loglevel,
+                                       handlers=loghandlers)
+            loggers[namespace] = logger
+            if namespace == 'pulsar' or default_loglevel is None:
+                default_loglevel = logger.level
+
+        default_loglevel = asyncio_loglevel = default_loglevel or 0
+        if asyncio_loglevel:
+            asyncio_loglevel = max(asyncio_loglevel,
+                                   logging._checkLevel('WARNING'))
         for namespace, loglevel in (('pulsar', default_loglevel),
                                     (name, default_loglevel),
-                                    ('asyncio', 'warning')):
+                                    ('asyncio', asyncio_loglevel)):
             if namespace not in loggers:
                 loggers[namespace] = configured_logger(namespace,
                                                        config=self.logconfig,
@@ -381,7 +393,7 @@ class Config(object):
         return self.copy()
 
     ########################################################################
-    ##    INTERNALS
+    #    INTERNALS
     def update_settings(self):
         for s in ordered_settings():
             setting = s().copy(name=self.name, prefix=self.prefix)
@@ -409,7 +421,7 @@ class SettingMeta(type):
     in the global ``KNOWN_SETTINGS`` list.'''
     def __new__(cls, name, bases, attrs):
         super_new = super(SettingMeta, cls).__new__
-        #parents = [b for b in bases if isinstance(b, SettingMeta)]
+        # parents = [b for b in bases if isinstance(b, SettingMeta)]
         val = attrs.get("validator")
         attrs["validator"] = wrap_method(val) if val else None
         if attrs.pop('virtual', False):
@@ -601,6 +613,12 @@ class Setting(SettingMeta('BaseSettings', (object,), {'virtual': True})):
         return self.copy()
 
 
+class TestOption(Setting):
+    virtual = True
+    app = 'test'
+    section = "Test"
+
+
 def validate_bool(val):
     if isinstance(val, bool):
         return val
@@ -691,7 +709,7 @@ def make_optparse_options(apps=None, exclude=None, include=None):
 
 
 ############################################################################
-##    Global Server Settings
+#    Global Server Settings
 section_docs['Global Server Settings'] = '''
 These settings are global in the sense that they are used by the arbiter
 as well as all pulsar workers. They are server configuration parameters.
@@ -737,9 +755,8 @@ class HttpParser(Global):
     flags = ["--http-py-parser"]
     action = "store_true"
     default = False
-    desc = '''Set the python parser as default HTTP parser.
-
-    Only used for benchmarking pourposes.
+    desc = '''\
+        Set the python parser as default HTTP parser
     '''
 
     def on_start(self):
@@ -846,6 +863,8 @@ class Loglevel(Global):
     name = "loglevel"
     flags = ["--log-level"]
     nargs = '+'
+    default = ['info']
+    validator = validate_list
     desc = '''
         The granularity of log outputs.
 
@@ -865,6 +884,7 @@ class Loglevel(Global):
 class LogHandlers(Global):
     name = "loghandlers"
     flags = ["--log-handlers"]
+    nargs = '+'
     default = ['console']
     validator = validate_list
     desc = '''Log handlers for pulsar server'''
@@ -944,7 +964,7 @@ class ExecutionId(Global):
 
 
 ############################################################################
-##    Worker Processes
+#    Worker Processes
 section_docs['Worker Processes'] = '''
 This group of configuration parameters control the number of actors
 for a given :class:`.Monitor`, the type of concurreny of the server and
@@ -1028,7 +1048,7 @@ class ThreadWorkers(Setting):
 
 
 ############################################################################
-##    APPLICATION HOOKS
+#    APPLICATION HOOKS
 section_docs['Application Hooks'] = '''
 Application hooks are functions which can be specified in a
 :ref:`config <setting-config>` file to perform custom tasks in a pulsar server.
