@@ -2,7 +2,6 @@
 '''
 import re
 from unicodedata import normalize
-from collections import namedtuple
 
 from .system import json
 from .pep import (ispy3k, native_str, to_string, iteritems, is_string,
@@ -10,7 +9,7 @@ from .pep import (ispy3k, native_str, to_string, iteritems, is_string,
 
 NOTHING = ('', b'', None)
 '''Tuple of elements considered as null.'''
-INLINE_TAGS = set(('input', 'meta', 'hr'))
+INLINE_TAGS = set(('input', 'link', 'meta', 'hr'))
 # The global attributes below can be used on any HTML element
 # class and style are misssing here since they are treated separately
 GLOBAL_HTML_ATTRIBUTES = ('accesskey', 'contenteditable', 'contextmenu', 'dir',
@@ -29,7 +28,7 @@ input_attr = lambda *t: e('type', 'autocomplete', 'autofocus', 'disabled',
                           'min', 'multiple', 'name', 'pattern', 'placeholder',
                           'readonly', 'required', 'size', 'step', 'value', *t)
 
-## HTML TAG ATTRIBUTES
+# HTML TAG ATTRIBUTES
 ############################################################################
 HTML_ATTRIBUTES['a'] = e('href', 'name', 'target')
 HTML_ATTRIBUTES['form'] = e('accept-charset', 'action', 'autocomplete',
@@ -47,6 +46,8 @@ HTML_ATTRIBUTES['input[type="image"]'] = input_attr(
 HTML_ATTRIBUTES['input[type="radio"]'] = input_attr('checked')
 HTML_ATTRIBUTES['input[type="submit"]'] = input_attr(
     'formaction', 'formenctype', 'formmethod', 'formtarget')
+HTML_ATTRIBUTES['link'] = e('href', 'hreflang', 'media', 'rel',
+                            'sizes', 'type')
 HTML_ATTRIBUTES['meta'] = e('name', 'charset', 'content')
 HTML_ATTRIBUTES['option'] = e('disabled', 'label', 'selected', 'value')
 HTML_ATTRIBUTES['script'] = e('async', 'charset', 'defer', 'src', 'type')
@@ -58,14 +59,14 @@ HTML_ATTRIBUTES['textarea'] = e('autofocus', 'cols', 'disabled', 'maxlength',
                                 'rows', 'wrap')
 HTML_ATTRIBUTES['th'] = e('colspan', 'headers', 'rowspan', 'scope')
 
-## DEFAULT HTML TAG CHILDREN
+# DEFAULT HTML TAG CHILDREN
 ############################################################################
 HTML_CHILDREN_TAG['ul'] = 'li'
 HTML_CHILDREN_TAG['ol'] = 'li'
 HTML_CHILDREN_TAG['select'] = 'option'
 
-## COMMON HTML ENTITIES
-## Check http://www.w3schools.com/tags/ref_symbols.asp for more
+# COMMON HTML ENTITIES
+# Check http://www.w3schools.com/tags/ref_symbols.asp for more
 ############################################################################
 HTML_NON_BREACKING_SPACE = '&nbsp;'
 '''HTML non breaking space symbol.'''
@@ -80,8 +81,6 @@ HTML_ENDASH = '&ndash;'
 HTML_EMDASH = '&mdash;'
 '''HTML -- symbol.'''
 
-csslink = namedtuple('cssentry', 'link condition')
-
 
 def tag_attributes(tag, type=None):
     '''Return a tuple of valid attributes for the HTML ``tag`` and optional
@@ -162,11 +161,20 @@ def capfirst(x):
 
 
 def nicename(name):
-    '''Make ``name`` a more user friendly string.'''
+    '''Make ``name`` a more user friendly string.
+
+    Capitalise the first letter and replace dash and underscores with a space
+    '''
     name = to_string(name)
     return capfirst(' '.join(name.replace('-', ' ').replace('_', ' ').split()))
 
 
+def plural(n, text, plural=None):
+    if n != 1:
+        text = plural or '%ss' % text
+    return '%d %s' % (n, text)
+
+
 class SafeString(string_type):
     __html__ = True
 
